import requests
from datetime import datetime, timedelta


API = {
    'ENDPOINT': 'https://services.nvd.nist.gov/rest/json/cves/2.0'
}
TODAY = datetime.now()
YESTERDAY = TODAY - timedelta(hours=36)


def get_cves() -> dict:
    """Get all CVEs from NVD API for the last 36 hours

    Returns:
        dict: All CVEs from NVD API for the last 36 hours

    Raises:
        requests.exceptions.HTTPError: If the request fails
    """
    response = requests.get(
        f'{API["ENDPOINT"]}?pubStartDate={YESTERDAY.strftime("%Y-%m-%dT%H:%M:%S.%f")}&pubEndDate={TODAY.strftime("%Y-%m-%dT%H:%M:%S.%f")}')

    if response.status_code == 200:
        return response.json()['vulnerabilities']

    if response.status_code == 404:
        raise requests.exceptions.HTTPError('No vulnerabilities found')

    if response.status_code == 400:
        raise requests.exceptions.HTTPError('Bad request')

    if response.status_code == 401:
        raise requests.exceptions.HTTPError(
            'Too many requests, try again later')

    if response.status_code == 500:
        raise requests.exceptions.HTTPError('Internal server error')

    raise requests.exceptions.HTTPError('Unknown error')
