import argparse
from cve_py.version import __version__


def init():
    parser = argparse.ArgumentParser(description='A python CVE tracker.')

    parser.add_argument('-V', '--version', action='version', version='%(prog)s ' + __version__,
                        help='Print the version number and exit.')

    parser.add_argument('-v', '--verbose', action='store_true',
                        help='Print verbose output.')

    database_group = parser.add_argument_group(
        'Database', 'Database related arguments.')

    database_group.add_argument('-d', '--directory', type=str, default='data',
                                help='The directory to store the database in. The default is data.')

    mail_group = parser.add_argument_group('Mail', 'Mail related arguments.')

    mail_group.add_argument('-m', '--mail', action='store_true',
                            help='Send an email with the results. You must either use the -c argument or ' +
                            'specify all the mail related arguments. (-s, -p, -u, -w, -o, -f, -j, -b)')
    mail_group.add_argument('-c', '--config', type=str, default='config.json', help='The path to the config file. ' +
                            'If no path is specified, the default config.json will be used. ' +
                            'Each setting can be overwritten by its respective command line argument.')

    config_group = parser.add_argument_group(
        'Config', 'Config related arguments. These arguments will overwrite the config file.')

    config_group.add_argument('-s', '--smtp-server', type=str,
                              help='The SMTP server to use.')
    config_group.add_argument('-p', '--smtp-port', type=int,
                              help='The SMTP port to use.')
    config_group.add_argument('-u', '--username', type=str,
                              help='The username to use when connecting to the SMTP server.')
    config_group.add_argument('-w', '--password', type=str,
                              help='The password to use when connecting to the SMTP server.')
    config_group.add_argument('-t', '--to-address', type=str,
                              help='The address to send the email to.')
    config_group.add_argument('-f', '--from-address', type=str,
                              help='The address to send the email from.')
    config_group.add_argument('-j', '--subject', type=str,
                              help='The subject of the email.')
    config_group.add_argument('-b', '--body', type=str,
                              help='The body of the email.')

    return parser.parse_args()
